@@ -38,6 +38,12 @@ class InvariantException(Exception):
         self.missing_fields = missing_fields
         super(InvariantException, self).__init__(*args, **kwargs)
 
+    def __str__(self):
+        return super(InvariantException, self).__str__() + \
+            ", invariant_errors=[{invariant_errors}], missing_fields=[{missing_fields}]".format(
+            invariant_errors=', '.join(str(e) for e in self.invariant_errors),
+            missing_fields=', '.join(self.missing_fields))
+
 
 def _store_types(dct, bases, destination_name, source_name):
     def to_list(elem):
